@@ -140,6 +140,21 @@
         <translation>Zadej heslo ke knihovně pro synchronizaci</translation>
     </message>
 </context>
+<context>
+    <name>ExtCommandsHandler</name>
+    <message>
+        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Failed to connect to background process, please try again later</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
+        <translation type="unfinished"/>
+    </message>
+</context>
 <context>
     <name>FileProviderManager</name>
     <message>
@@ -364,6 +379,26 @@
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Advanced Options</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sync Root Folder Name:</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sync root folder name cannot be empty</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MessagePoller</name>
@@ -798,6 +833,10 @@
         <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
         <translation type="unfinished"/>
     </message>
+    <message>
+        <source>Failed to change library name since some files are opened in it</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>RemoteWipeService</name>
