@@ -140,6 +140,21 @@
         <translation>Passwort der verschlüsselten Bibliothek</translation>
     </message>
 </context>
+<context>
+    <name>ExtCommandsHandler</name>
+    <message>
+        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
+        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; entfernen? Heruntergeladene und hochgeladene Dateien werden nicht gelöscht.</translation>
+    </message>
+    <message>
+        <source>Failed to connect to background process, please try again later</source>
+        <translation>Der Hintergrundprozess konnte nicht aufgerufen werden. Bitte versuchen Sie es später noch einmal</translation>
+    </message>
+    <message>
+        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
+        <translation>Möchten Sie wirklich den Account aus &quot;%1&quot; neu synchronisieren? Heruntergeladene und hochgeladene Dateien werden nicht gelöscht.</translation>
+    </message>
+</context>
 <context>
     <name>FileProviderManager</name>
     <message>
@@ -364,6 +379,26 @@
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Zum Beispiel: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <source>Advanced Options</source>
+        <translation>Erweiterte Einstellungen</translation>
+    </message>
+    <message>
+        <source>Sync Root Folder Name:</source>
+        <translation>Basisordner für die Synchronisierung:</translation>
+    </message>
+    <message>
+        <source>Sync root folder name cannot be empty</source>
+        <translation>Basisordner für die Synchronisierung ist erforderlich</translation>
+    </message>
+    <message>
+        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
+        <translation>Die Bezeichnung des Basisordners für die Synchronisierung darf nicht enthalten: &lt; &gt; : &quot; / \ | ? *</translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Synchronisierungen dieses Accounts werden in einem Dateipfad abgelegt, der etwa so lautet: &apos;C:\Users\XY\seadrive_root\&amp;lt;BASISORDNER&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
 </context>
 <context>
     <name>MessagePoller</name>
@@ -798,6 +833,10 @@
         <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
         <translation>Der Dateipfad hat einen Konflikt mit der Großkleinschreibung einer bestehenden Datei oder eines Ordners. Herunterladen wird nicht möglich sein</translation>
     </message>
+    <message>
+        <source>Failed to change library name since some files are opened in it</source>
+        <translation>Der Name der Bibliothek konnte nicht geändert werden, da Dateien in ihr geöffnet sind</translation>
+    </message>
 </context>
 <context>
     <name>RemoteWipeService</name>
@@ -999,7 +1038,7 @@
     </message>
     <message>
         <source>Show file sync errors</source>
-        <translation>Dateifehler beim Synchronisieren anzeigen</translation>
+        <translation>Fehler bei der Dateisynchronisation anzeigen</translation>
     </message>
     <message>
         <source>Open &amp;logs folder</source>
@@ -1415,7 +1454,7 @@
     <name>SyncErrorsDialog</name>
     <message>
         <source>File Sync Errors</source>
-        <translation>Dateifehler bei der Synchronisation</translation>
+        <translation>Fehler bei der Dateisynchronisation</translation>
     </message>
     <message>
         <source>No sync errors.</source>
