@@ -140,6 +140,21 @@
         <translation>Введите пароль библиотеки для синхронизации</translation>
     </message>
 </context>
+<context>
+    <name>ExtCommandsHandler</name>
+    <message>
+        <source>Are you sure to remove account from &quot;%1&quot;? Downloaded and uploading files will not be removed.</source>
+        <translation>Вы уверены, что необходимо удалить учетную запись с &quot;%1&quot;? Скачанные и загружаемые файлы не будут удалены.</translation>
+    </message>
+    <message>
+        <source>Failed to connect to background process, please try again later</source>
+        <translation>Не удалось подключиться к фоновому процессу. Повторите попытку позже</translation>
+    </message>
+    <message>
+        <source>Are you sure to resync account from &quot;%1&quot;? Downloaded and uploading files will not be removed</source>
+        <translation>Вы уверены, что необходимо повторно синхронизировать учетную запись с &quot;%1&quot;? Скачанные и загружаемые файлы не будут удалены</translation>
+    </message>
+</context>
 <context>
     <name>FileProviderManager</name>
     <message>
@@ -364,6 +379,26 @@
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
         <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Например: https://example.your-server.com&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
+    <message>
+        <source>Advanced Options</source>
+        <translation>Расширенные параметры</translation>
+    </message>
+    <message>
+        <source>Sync Root Folder Name:</source>
+        <translation>Имя корневой папки синхронизации:</translation>
+    </message>
+    <message>
+        <source>Sync root folder name cannot be empty</source>
+        <translation>Имя корневой папки синхронизации не может быть пустым</translation>
+    </message>
+    <message>
+        <source>Sync root folder name cannot contain the following characters: &lt; &gt; : &quot; / \ | ? *</source>
+        <translation>Имя корневой папки синхронизации не может содержать следующие символы: &lt; &gt; : &quot; / \ | ? *</translation>
+    </message>
+    <message>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Files in this account will be synced under the path like &apos;C:\Users\Jim\seadrive_root\&amp;lt;sync root folder name&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Файлы в этой учетной записи будут синхронизированы по пути, подобному &apos;C:\Users\Jim\seadrive_root\&amp;lt;имя корневой папки синхронизации&amp;gt;&apos;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
 </context>
 <context>
     <name>MessagePoller</name>
@@ -798,6 +833,10 @@
         <source>Path has character case conflict with existing file or folder. Will not be downloaded</source>
         <translation>Путь конфликтует с регистром символов существующего файла или папки. Не будет загружен.</translation>
     </message>
+    <message>
+        <source>Failed to change library name since some files are opened in it</source>
+        <translation>Не удалось изменить название библиотеки, так как в ней открыты некоторые файлы</translation>
+    </message>
 </context>
 <context>
     <name>RemoteWipeService</name>
